@@ -203,6 +203,23 @@ def detect_ie(method):
     return wrapper
 
 
+
+def io_init(method):
+
+    @functools.wraps(method)
+    def wrapper(self, *args, **kwargs):
+
+
+
+        return method(self, *args, **kwargs)
+
+    return wrapper
+
+
+    pass
+
+
+
 class RequestHandler(tornado.web.RequestHandler):
     def __init__(self, application, request, **kwargs):
         '''
@@ -240,8 +257,8 @@ class RequestHandler(tornado.web.RequestHandler):
         # self.db = self.application.settings.get('db', NotImplemented)
         # self.acct_db = self.application.settings.get('acct_db', NotImplemented)
 
-        # self.cache_db = self.application.settings.get('cache_db', NotImplemented)
-        # self.cache_config = self.application.settings.get('cache_config', NotImplemented)
+        self.cache_db = self.application.settings.get('cache_db', NotImplemented)
+
         #
         # self.files_db = self.application.settings.get('files_db', NotImplemented)
         # self.dbs = self.application.settings.get('dbs', NotImplemented)
@@ -260,7 +277,7 @@ class RequestHandler(tornado.web.RequestHandler):
         self.smtp=None
         self.db = None
         self.acct_db = None
-        self.cache_db=None
+        # self.cache_db=None
         self.files_db=None
         self.dbs=None
         self.session=None
